searchData={"items":[{"type":"module","title":"ExAws.CodeDeploy","doc":"Operations on AWS CodeDeploy\n\nThe documentation and types provided lean heavily on the [AWS documentation for\nCodeDeploy](https://docs.aws.amazon.com/codedeploy/index.html). The AWS documentation is the\ndefinitive source of information and should be consulted to understand how to use CodeDeploy and\nits API functions.\n\nGenerally the functions take required parameters separately from any optional arguments. The\noptional arguments are passed as a Map (with a defined type).\n\nThe defined types for the Maps used to pass optional arguments use the standard Elixir snake-case\nfor keys. The API itself uses camel-case Strings for keys. The library provides the conversion.\nMost of the API keys use a lower-case letter for the first word and upper-case for the subsequent\nwords. There are exceptions to this rule. The exceptions are handled by the library so an Elixir\ndeveloper can just use standard snake-case for all the keys.","ref":"ExAws.CodeDeploy.html"},{"type":"module","title":"Description - ExAws.CodeDeploy","doc":"CodeDeploy is a deployment service that automates application deployments to Amazon EC2 instances,\non-premises instances, serverless Lambda functions, or Amazon ECS services.\n\nYou can deploy a nearly unlimited variety of application content, including:\n\n- Code\n- Serverless AWS Lambda functions\n- Web and configuration files\n- Executables\n- Packages\n- Scripts\n- Multimedia files","ref":"ExAws.CodeDeploy.html#module-description"},{"type":"module","title":"Resources - ExAws.CodeDeploy","doc":"- [CodeDeploy User Guide](https://docs.aws.amazon.com/codedeploy/latest/userguide)\n- [CodeDeploy API Reference Guide](https://docs.aws.amazon.com/codedeploy/latest/APIReference/)\n- [CLI Reference for CodeDeploy](https://docs.aws.amazon.com/cli/latest/reference/deploy/index.html)\n- [CodeDeploy Developer Forum](https://forums.aws.amazon.com/forum.jspa?forumID=179)","ref":"ExAws.CodeDeploy.html#module-resources"},{"type":"function","title":"ExAws.CodeDeploy.add_tags_to_on_premises_instances/2","doc":"Adds tags to on-premises instances.\n\n_Note: although tags can be specified using `t:primitive_tag/0` it's preferred to use the\n`t:tag/0` syntax_.","ref":"ExAws.CodeDeploy.html#add_tags_to_on_premises_instances/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.add_tags_to_on_premises_instances/2","doc":"iex> tags = [%{key: \"key1\", value: \"value\"}, %{key: \"key2\", value: \"value\"}]\n    iex> instances = [\"i-1234\", \"i-59922\"]\n    iex> ExAws.CodeDeploy.add_tags_to_on_premises_instances(instances, tags)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"instanceNames\" => [\"i-1234\", \"i-59922\"],\n        \"tags\" => [\n          %{\"Key\" => \"key1\", \"Value\" => \"value\"},\n          %{\"Key\" => \"key2\", \"Value\" => \"value\"}\n        ]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.AddTagsToOnPremisesInstances\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#add_tags_to_on_premises_instances/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.batch_get_application_revisions/2","doc":"Gets information about one or more application revisions\n\nThe maximum number of application revisions that can be returned is 25.","ref":"ExAws.CodeDeploy.html#batch_get_application_revisions/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.batch_get_application_revisions/2","doc":"iex> revisions = [\n    ...>%{\n    ...>  git_hub_location: %{commit_id: \"fa85936EXAMPLEa31736c051f10d77297EXAMPLE\",\n    ...>  repository: \"my-github-token/my-repository\"},\n    ...>  revision_type: \"GitHub\"\n    ...> }]\n    iex> ExAws.CodeDeploy.batch_get_application_revisions(\"my-codedeploy-application\", revisions)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"my-codedeploy-application\",\n        \"revisions\" => [\n          %{\n            \"gitHubLocation\" => %{\n              \"commitId\" => \"fa85936EXAMPLEa31736c051f10d77297EXAMPLE\",\n              \"repository\" => \"my-github-token/my-repository\"\n            },\n            \"revisionType\" => \"GitHub\"\n          }\n        ]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.BatchGetApplicationRevisions\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#batch_get_application_revisions/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.batch_get_applications/1","doc":"Gets information about one or more applications. The maximum number of applications that can be\nreturned is 100.","ref":"ExAws.CodeDeploy.html#batch_get_applications/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.batch_get_applications/1","doc":"iex> ExAws.CodeDeploy.batch_get_applications([\"TestDeploy1\", \"TestDeploy2\"])\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"applicationNames\" => [\"TestDeploy1\", \"TestDeploy2\"]},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.BatchGetApplications\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#batch_get_applications/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.batch_get_deployment_groups/2","doc":"Gets information about one or more deployment groups.","ref":"ExAws.CodeDeploy.html#batch_get_deployment_groups/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.batch_get_deployment_groups/2","doc":"iex> application_name = \"TestApp-us-east-1\"\n    iex> deployment_group_names = [\"dep-group-def-456\", \"dep-group-jkl-234\"]\n    iex> ExAws.CodeDeploy.batch_get_deployment_groups(application_name, deployment_group_names)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"TestApp-us-east-1\",\n        \"deploymentGroupNames\" => [\"dep-group-def-456\", \"dep-group-jkl-234\"]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.BatchGetDeploymentGroups\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#batch_get_deployment_groups/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.batch_get_deployment_instances/2","doc":"Gets information about one or more instance that are part of a deployment group.\n\nYou can use `list_deployment_instances/1` to get a list of instances deployed to by a\n`t:deployment_id/0` but you need this function get details on the instances like startTime,\nendTime, lastUpdatedAt and instanceType.","ref":"ExAws.CodeDeploy.html#batch_get_deployment_instances/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.batch_get_deployment_instances/2","doc":"iex> ExAws.CodeDeploy.batch_get_deployment_instances(\"TestDeploy\", [\"i-23324\"])\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentId\" => \"TestDeploy\", \"instanceIds\" => [\"i-23324\"]},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.BatchGetDeploymentInstances\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#batch_get_deployment_instances/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.batch_get_deployment_targets/2","doc":"Returns an array of one or more targets associated with a deployment. This method works with all\ncompute types and should be used instead of the deprecated BatchGetDeploymentInstances. The\nmaximum number of deployment target IDs you can specify is 25.\n\nThe type of targets returned depends on the deployment's compute platform or deployment method:\n\n- EC2/On-premises: Information about Amazon EC2 instance targets.\n- AWS Lambda : Information about Lambda functions targets.\n- Amazon ECS: Information about Amazon ECS service targets.\n- CloudFormation: Information about targets of blue/green deployments initiated by a\n  CloudFormation stack update.","ref":"ExAws.CodeDeploy.html#batch_get_deployment_targets/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.batch_get_deployment_targets/2","doc":"iex> ExAws.CodeDeploy.batch_get_deployment_targets(\"d-1A2B3C4D5\", [\"i-01a2b3c4d5e6f1111\"])\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"deploymentId\" => \"d-1A2B3C4D5\",\n        \"targetIds\" => [\"i-01a2b3c4d5e6f1111\"]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.BatchGetDeploymentTargets\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#batch_get_deployment_targets/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.batch_get_deployments/1","doc":"Gets information about one or more deployments. The maximum number of deployments that can be\nreturned is 25.","ref":"ExAws.CodeDeploy.html#batch_get_deployments/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.batch_get_deployments/1","doc":"iex> ExAws.CodeDeploy.batch_get_deployments([\"d-A1B2C3111\", \"d-A1B2C3222\"])\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentIds\" => [\"d-A1B2C3111\", \"d-A1B2C3222\"]},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.BatchGetDeployments\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#batch_get_deployments/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.batch_get_on_premises_instances/1","doc":"Gets information about one or more on-premises instances.","ref":"ExAws.CodeDeploy.html#batch_get_on_premises_instances/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.batch_get_on_premises_instances/1","doc":"iex> ExAws.CodeDeploy.batch_get_on_premises_instances([\"i-23324\", \"i-43231\"])\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"instanceNames\" => [\"i-23324\", \"i-43231\"]},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.BatchGetOnPremisesInstances\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#batch_get_on_premises_instances/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.continue_deployment/2","doc":"For a blue/green deployment, starts the process of rerouting traffic.\n\nStart the process of rerouting traffic from instances in the original environment to instances in\nthe replacement environment without waiting for a specified wait time to elapse. (Traffic\nrerouting, which is achieved by registering instances in the replacement environment with the load\nbalancer, can start as soon as all instances have a status of Ready.)\n\nThe `deployment_wait_type` is optional. If any value other than \"READY_WAIT\" or \"TERMINATION_WAIT\"\nis provided then it is not sent with the API request.","ref":"ExAws.CodeDeploy.html#continue_deployment/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.continue_deployment/2","doc":"iex> ExAws.CodeDeploy.continue_deployment(\"d-1234\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentId\" => \"d-1234\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ContinueDeployment\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }\n\n    iex> ExAws.CodeDeploy.continue_deployment(\"d-1234\", \"TERMINATION_WAIT\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"deploymentId\" => \"d-1234\",\n        \"deploymentWaitType\" => \"TERMINATION_WAIT\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ContinueDeployment\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#continue_deployment/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.create_application/3","doc":"Creates an Application\n\n- application_name - Required. must be unique with the applicable IAM user or AWS account.\n- compute_platform - Optional. The destination platform type for the deployment. Valid values\n  are \"Server\", \"Lambda\" or \"ECS\"\n- tags - Optional. The metadata that you apply to CodeDeploy applications to help you\n  organize and categorize them. Each tag consists of a key and an optional value,\n  both of which you define.","ref":"ExAws.CodeDeploy.html#create_application/3"},{"type":"function","title":"Examples - ExAws.CodeDeploy.create_application/3","doc":"iex> ExAws.CodeDeploy.create_application(\"TestDeploy\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"TestDeploy\",\n        \"computePlatform\" => \"Server\",\n        \"tags\" => []\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.CreateApplication\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }\n\n    iex> tags = [{\"key1\", \"value\"}, {\"key2\", \"value\"}]\n    iex> ExAws.CodeDeploy.create_application(\"TestDeploy\", \"Server\", tags)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"TestDeploy\",\n        \"computePlatform\" => \"Server\",\n        \"tags\" => [\n          %{\"Key\" => \"key1\", \"Value\" => \"value\"},\n          %{\"Key\" => \"key2\", \"Value\" => \"value\"}\n        ]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.CreateApplication\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#create_application/3-examples"},{"type":"function","title":"ExAws.CodeDeploy.create_deployment/2","doc":"Deploys an application revision through the specified deployment group.\n\nCaller is responsible for defining the deployment_details in a manner that\nmatches what Amazon expects. See unit test.","ref":"ExAws.CodeDeploy.html#create_deployment/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.create_deployment/2","doc":"iex> deployment_details = %{\n    ...>   deployment_group_name: \"dep-01\",\n    ...>   auto_rollback_configuration: %{\n    ...>    enabled: true,\n    ...>    events: [\"DEPLOYMENT_FAILURE\", \"DEPLOYMENT_STOP_ON_ALARM\"]\n    ...>   },\n    ...>   revision: %{\n    ...>    git_hub_location: %{commit_id: \"fa85936EXAMPLEa31736c051f10d77297EXAMPLE\",\n    ...>    repository: \"my-github-token/my-repository\"},\n    ...>    revision_type: \"GitHub\"\n    ...>   }\n    ...> }\n    iex> ExAws.CodeDeploy.create_deployment(\"my-app\", deployment_details)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"my-app\",\n        \"autoRollbackConfiguration\" => %{\n          \"enabled\" => true,\n          \"events\" => [\"DEPLOYMENT_FAILURE\", \"DEPLOYMENT_STOP_ON_ALARM\"]\n        },\n        \"deploymentGroupName\" => \"dep-01\",\n        \"revision\" => %{\n          \"gitHubLocation\" => %{\n            \"commitId\" => \"fa85936EXAMPLEa31736c051f10d77297EXAMPLE\",\n            \"repository\" => \"my-github-token/my-repository\"\n          },\n          \"revisionType\" => \"GitHub\"\n        }\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.CreateDeployment\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#create_deployment/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.create_deployment_config/2","doc":"Creates a deployment configuration","ref":"ExAws.CodeDeploy.html#create_deployment_config/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.create_deployment_config/2","doc":"iex> ExAws.CodeDeploy.create_deployment_config(\"deploy_config1\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentConfigName\" => \"deploy_config1\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.CreateDeployment\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }\n\n\n    iex> deployment_config_details = %{minimim_healthy_hosts: %{type: \"HOST_COUNT\", value: 2}}\n    iex> ExAws.CodeDeploy.create_deployment_config(\"deploy_config1\", deployment_config_details)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"deploymentConfigName\" => \"deploy_config1\",\n        \"minimimHealthyHosts\" => %{\"type\" => \"HOST_COUNT\", \"value\" => 2}\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.CreateDeployment\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#create_deployment_config/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.create_deployment_group/4","doc":"Creates a deployment group to which application revisions are deployed","ref":"ExAws.CodeDeploy.html#create_deployment_group/4"},{"type":"function","title":"Examples - ExAws.CodeDeploy.create_deployment_group/4","doc":"iex> application_name = \"WordPress_App\"\n    iex> deployment_group_name = \"WordPress_DG\"\n    iex> service_role_arn = \"arn:aws:iam::123456789012:role/CodeDeployDemoRole\"\n    iex> deployment_group_details = %{\n    ...>   auto_scaling_groups: [\"CodeDeployDemo-ASG\"],\n    ...>   deployment_config_name: \"CodeDeployDefault.OneAtATime\",\n    ...>   ec2_tag_filters: [%{key: \"Name\", value: \"CodeDeployDemo\", type: \"KEY_AND_VALUE\"}]\n    ...> }\n    iex> ExAws.CodeDeploy.create_deployment_group(application_name, deployment_group_name, service_role_arn, deployment_group_details)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"WordPress_App\",\n        \"autoScalingGroups\" => [\"CodeDeployDemo-ASG\"],\n        \"deploymentConfigName\" => \"CodeDeployDefault.OneAtATime\",\n        \"deploymnentGroupName\" => \"WordPress_DG\",\n        \"ec2TagFilters\" => [\n          %{\"Key\" => \"Name\", \"Type\" => \"KEY_AND_VALUE\", \"Value\" => \"CodeDeployDemo\"}\n        ],\n        \"serviceRoleArn\" => \"arn:aws:iam::123456789012:role/CodeDeployDemoRole\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.CreateDeploymentGroup\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#create_deployment_group/4-examples"},{"type":"function","title":"ExAws.CodeDeploy.delete_application/1","doc":"Deletes an application.\n\napplication_name: The name of an AWS CodeDeploy application associated with the applicable IAM\nuser or AWS account.","ref":"ExAws.CodeDeploy.html#delete_application/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.delete_application/1","doc":"iex> ExAws.CodeDeploy.delete_application(\"TestDeploy\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"applicationName\" => \"TestDeploy\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.DeleteApplication\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#delete_application/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.delete_deployment_config/1","doc":"Deletes a deployment configuration.\n\nA deployment configuration cannot be deleted if it is currently in use. Predefined configurations\ncannot be deleted.","ref":"ExAws.CodeDeploy.html#delete_deployment_config/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.delete_deployment_config/1","doc":"iex> ExAws.CodeDeploy.delete_deployment_config(\"TestConfig\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentConfigName\" => \"TestConfig\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.DeleteDeploymentConfig\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#delete_deployment_config/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.delete_deployment_group/2","doc":"Deletes a deployment group.","ref":"ExAws.CodeDeploy.html#delete_deployment_group/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.delete_deployment_group/2","doc":"iex> ExAws.CodeDeploy.delete_deployment_group(\"TestApp\", \"TestDeploy\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"applicationName\" => \"TestApp\", \"deploymentGroupName\" => \"TestDeploy\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.DeleteDeploymentGroup\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#delete_deployment_group/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.delete_git_hub_account_token/1","doc":"Deletes a GitHub account connection.","ref":"ExAws.CodeDeploy.html#delete_git_hub_account_token/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.delete_git_hub_account_token/1","doc":"iex> ExAws.CodeDeploy.delete_git_hub_account_token(\"token\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"tokenName\" => \"token\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.DeleteGitHubAccountToken\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#delete_git_hub_account_token/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.delete_resources_by_external_id/1","doc":"Deletes resources linked to an external ID. This action only applies if you have configured\nblue/green deployments through AWS CloudFormation.\n\nIt is not necessary to call this action directly. CloudFormation calls it on your behalf when it\nneeds to delete stack resources. This action is offered publicly in case you need to delete\nresources to comply with General Data Protection Regulation (GDPR) requirements.","ref":"ExAws.CodeDeploy.html#delete_resources_by_external_id/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.delete_resources_by_external_id/1","doc":"iex> ExAws.CodeDeploy.delete_resources_by_external_id(\"external-12345\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"externalId\" => \"external-12345\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.DeleteResourcesByExternalId\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#delete_resources_by_external_id/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.deregister_on_premises_instance/1","doc":"Deregisters an on-premises instance.","ref":"ExAws.CodeDeploy.html#deregister_on_premises_instance/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.deregister_on_premises_instance/1","doc":"iex> ExAws.CodeDeploy.deregister_on_premises_instance(\"i-1234\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"instanceName\" => \"i-1234\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.DeregisterOnPremisesInstance\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#deregister_on_premises_instance/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.get_application/1","doc":"Gets information about an application.","ref":"ExAws.CodeDeploy.html#get_application/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.get_application/1","doc":"iex> ExAws.CodeDeploy.get_application(\"TestApp\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"applicationName\" => \"TestApp\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.GetApplication\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#get_application/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.get_application_revision/2","doc":"Gets information about an application revision.\n\nCaller is responsible for defining the revision details (if needed)\nin a manner that matches what Amazon expects. See unit test.","ref":"ExAws.CodeDeploy.html#get_application_revision/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.get_application_revision/2","doc":"iex> ExAws.CodeDeploy.get_application_revision(\"TestApp\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"applicationName\" => \"TestApp\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.GetApplicationRevision\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#get_application_revision/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.get_deployment/1","doc":"Gets information about a deployment.","ref":"ExAws.CodeDeploy.html#get_deployment/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.get_deployment/1","doc":"iex> ExAws.CodeDeploy.get_deployment(\"deploy_id\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentId\" => \"deploy_id\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.GetDeployment\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#get_deployment/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.get_deployment_config/1","doc":"Gets information about a deployment configuration. See `create_deployment/2`","ref":"ExAws.CodeDeploy.html#get_deployment_config/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.get_deployment_config/1","doc":"iex> ExAws.CodeDeploy.get_deployment_config(\"deploy-config\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentConfigName\" => \"deploy-config\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.GetDeploymentConfig\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#get_deployment_config/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.get_deployment_group/2","doc":"Gets information about a deployment group.","ref":"ExAws.CodeDeploy.html#get_deployment_group/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.get_deployment_group/2","doc":"iex> ExAws.CodeDeploy.get_deployment_group(\"TestApp-us-east-1\", \"dep-group-def-456\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"TestApp-us-east-1\",\n        \"deploymentGroupName\" => \"dep-group-def-456\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.GetDeploymentGroup\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#get_deployment_group/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.get_deployment_instance/2","doc":"Gets information about an instance as part of a deployment.","ref":"ExAws.CodeDeploy.html#get_deployment_instance/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.get_deployment_instance/2","doc":"iex> ExAws.CodeDeploy.get_deployment_instance(\"d-7539MBT7C\", \"i-496636f700EXAMPLE\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"deploymentId\" => \"d-7539MBT7C\",\n        \"instanceId\" => \"i-496636f700EXAMPLE\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.GetDeploymentInstance\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#get_deployment_instance/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.get_deployment_target/2","doc":"Returns information about a deployment target","ref":"ExAws.CodeDeploy.html#get_deployment_target/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.get_deployment_target/2","doc":"iex> ExAws.CodeDeploy.get_deployment_target(\"d-7539MBT7C\", \"i-49663TARGET\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentId\" => \"d-7539MBT7C\", \"targetId\" => \"i-49663TARGET\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.GetDeploymentTarget\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#get_deployment_target/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.get_on_premises_instance/1","doc":"Gets information about an on-premises instance","ref":"ExAws.CodeDeploy.html#get_on_premises_instance/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.get_on_premises_instance/1","doc":"iex> ExAws.CodeDeploy.get_on_premises_instance(\"AssetTag12010298EX\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"instanceName\" => \"AssetTag12010298EX\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.GetOnPremisesInstance\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#get_on_premises_instance/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.list_application_revisions/2","doc":"Lists information about revisions for an application","ref":"ExAws.CodeDeploy.html#list_application_revisions/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.list_application_revisions/2","doc":"iex> list_application_revisions = %{\n    ...>   s3_bucket: \"CodeDeployDemoBucket\",\n    ...>   deployed: \"exclude\",\n    ...>   sort_by: \"lastUsedTime\",\n    ...>   sort_order: \"descending\"\n    ...> }\n    iex> ExAws.CodeDeploy.list_application_revisions(\"WordPress_App\", list_application_revisions)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"WordPress_App\",\n        \"deployed\" => \"exclude\",\n        \"s3Bucket\" => \"CodeDeployDemoBucket\",\n        \"sortBy\" => \"lastUsedTime\",\n        \"sortOrder\" => \"descending\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListApplicationRevisions\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_application_revisions/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.list_applications/1","doc":"Lists the applications registered with the applicable IAM user or AWS account.","ref":"ExAws.CodeDeploy.html#list_applications/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.list_applications/1","doc":"iex> ExAws.CodeDeploy.list_applications()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListApplications\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }\n\n    iex> ExAws.CodeDeploy.list_applications([{:next_token, \"AB1234Z6921\"}])\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"nextToken\" => \"AB1234Z6921\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListApplications\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_applications/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.list_deployment_configs/1","doc":"Lists the deployment configurations with the applicable IAM user or AWS account.","ref":"ExAws.CodeDeploy.html#list_deployment_configs/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.list_deployment_configs/1","doc":"iex> ExAws.CodeDeploy.list_deployment_configs()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListDeploymentConfigs\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_deployment_configs/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.list_deployment_groups/2","doc":"Lists the deployment groups for an application registered with the applicable IAM user or AWS account.\n\nThis returns results that look like:\n\n```\n  {:ok,\n    %{\n      \"applicationName\" => \" \",\n      \"deploymentGroups\" => [\"<your deploy group\", ...]\n    }}\n```","ref":"ExAws.CodeDeploy.html#list_deployment_groups/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.list_deployment_groups/2","doc":"iex> ExAws.CodeDeploy.list_deployment_groups(\"application\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"applicationName\" => \"application\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListDeploymentGroups\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_deployment_groups/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.list_deployment_instances/2","doc":"Lists the instance for a deployment associated with the applicable IAM user or AWS account.","ref":"ExAws.CodeDeploy.html#list_deployment_instances/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.list_deployment_instances/2","doc":"iex> ExAws.CodeDeploy.list_deployment_instances(\"deploy_id\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentId\" => \"deploy_id\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListDeploymentInstances\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_deployment_instances/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.list_deployment_targets/2","doc":"Returns an array of target IDs that are associated a deployment\n\n    iex> target_filters = %{target_filters: %{target_status: [\"Failed\", \"InProgress\"]}}\n    iex> ExAws.CodeDeploy.list_deployment_targets(\"d-A1B2C3111\", target_filters)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"deploymentId\" => \"d-A1B2C3111\",\n        \"targetFilters\" => %{\"TargetStatus\" => [\"Failed\", \"InProgress\"]}\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListDeploymentTargets\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_deployment_targets/2"},{"type":"function","title":"ExAws.CodeDeploy.list_deployments/1","doc":"Lists the deployments in a deployment group for an application registered with the applicable IAM user or AWS account.\n\nThe start and end times are in Epoch time. To leave either open-ended pass in nil. Example:\nlist_deployments(create_time_range: %{start: 1520963748, end: nil})","ref":"ExAws.CodeDeploy.html#list_deployments/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.list_deployments/1","doc":"iex> ExAws.CodeDeploy.list_deployments()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListDeployments\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_deployments/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.list_git_hub_account_token_names/1","doc":"Lists the names of stored connections to GitHub accounts","ref":"ExAws.CodeDeploy.html#list_git_hub_account_token_names/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.list_git_hub_account_token_names/1","doc":"iex> ExAws.CodeDeploy.list_git_hub_account_token_names()\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListGitHubAccountTokenNames\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_git_hub_account_token_names/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.list_on_premises_instances/1","doc":"Gets a list of names for one or more on-premises instances.\n\nUnless otherwise specified, both registered and deregistered on-premises instance names are\nlisted. To list only registered or deregistered on-premises instance names, use the registration\nstatus parameter.","ref":"ExAws.CodeDeploy.html#list_on_premises_instances/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.list_on_premises_instances/1","doc":"iex> opts = %{\n    ...>   registration_status: \"Registered\",\n    ...>   tag_filters: [%{key: \"Name\", value: \"CodeDeployDemo-OnPrem\", type: \"KEY_AND_VALUE\"}]\n    ...> }\n    iex> ExAws.CodeDeploy.list_on_premises_instances(opts)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"registrationStatus\" => \"Registered\",\n        \"tagFilters\" => [\n          %{\n            \"Key\" => \"Name\",\n            \"Type\" => \"KEY_AND_VALUE\",\n            \"Value\" => \"CodeDeployDemo-OnPrem\"\n          }\n        ]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListOnPremisesInstances\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_on_premises_instances/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.list_tags_for_resource/2","doc":"Returns a list of tags for the resource identified by a specified Amazon Resource Name (ARN). Tags\nare used to organize and categorize your CodeDeploy resources.","ref":"ExAws.CodeDeploy.html#list_tags_for_resource/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.list_tags_for_resource/2","doc":"iex> resource_arn = \"arn:aws:codedeploy:us-west-2:111122223333:application:testApp\"\n    iex> ExAws.CodeDeploy.list_tags_for_resource(resource_arn)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"resourceArn\" => \"arn:aws:codedeploy:us-west-2:111122223333:application:testApp\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListTagsForResource\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }\n\n    iex> resource_arn = \"arn:aws:codedeploy:us-west-2:111122223333:application:testApp\"\n    iex> ExAws.CodeDeploy.list_tags_for_resource(resource_arn, %{next_token: \"abcd123EXAMPLE\"})\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"nextToken\" => \"abcd123EXAMPLE\",\n        \"resourceArn\" => \"arn:aws:codedeploy:us-west-2:111122223333:application:testApp\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.ListTagsForResource\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#list_tags_for_resource/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.put_lifecycle_event_hook_execution_status/2","doc":"Sets the result of a Lambda validation function. The function validates one or\nboth lifecycle events (BeforeAllowTraffic and AfterAllowTraffic) and returns\nSucceeded or Failed.","ref":"ExAws.CodeDeploy.html#put_lifecycle_event_hook_execution_status/2"},{"type":"function","title":"ExAws.CodeDeploy.register_application_revision/3","doc":"Registers with AWS CodeDeploy a revision for the specified application","ref":"ExAws.CodeDeploy.html#register_application_revision/3"},{"type":"function","title":"Examples - ExAws.CodeDeploy.register_application_revision/3","doc":"iex> application_name = \"WordPress_App\"\n    iex> revision_location = %{s3_location: %{bucket: \"CodeDeployDemoBucket\", key: \"RevisedWordPressApp.zip\", bundle_type: \"zip\", e_tag: \"cecc9b8a08eac650a6e71fdb88EXAMPLE\"}}\n    iex> opts = %{description: \"Revised WordPress application\"}\n    iex> ExAws.CodeDeploy.register_application_revision(application_name, revision_location, opts)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"WordPress_App\",\n        \"description\" => \"Revised WordPress application\",\n        \"revisionLocation\" => %{\n          \"s3Location\" => %{\n            \"bucket\" => \"CodeDeployDemoBucket\",\n            \"bundleType\" => \"zip\",\n            \"eTag\" => \"cecc9b8a08eac650a6e71fdb88EXAMPLE\",\n            \"key\" => \"RevisedWordPressApp.zip\"\n          }\n        }\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.RegisterApplicationRevision\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#register_application_revision/3-examples"},{"type":"function","title":"ExAws.CodeDeploy.register_on_premises_instance/2","doc":"Registers an on-premises instance.\n\nOnly one IAM ARN (an IAM session ARN or IAM user ARN) is supported in the request. You cannot use\nboth.","ref":"ExAws.CodeDeploy.html#register_on_premises_instance/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.register_on_premises_instance/2","doc":"iex> arn_info = %{iam_session_arn: \"3242342ABC\"}\n    iex> ExAws.CodeDeploy.register_on_premises_instance(\"i-12345\", arn_info)\n    ExAws.CodeDeploy.register_on_premises_instance(\"i-12345\", %{iam_session_arn: \"3242342ABC\"})\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"iamSessionArn\" => \"3242342ABC\", \"instanceName\" => \"i-12345\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.RegisterOnPremisesInstance\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#register_on_premises_instance/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.remove_tags_from_on_premises_instances/2","doc":"Removes one or more tags from one or more on-premises instances","ref":"ExAws.CodeDeploy.html#remove_tags_from_on_premises_instances/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.remove_tags_from_on_premises_instances/2","doc":"iex> instance_names = [\"AssetTag12010298EX\", \"AssetTag23121309EX\"]\n    iex> tags = [%{key: \"Name\", value: \"CodeDeployDemo-OnPrem\"}]\n    iex> ExAws.CodeDeploy.remove_tags_from_on_premises_instances(instance_names, tags)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"instanceNames\" => [\"AssetTag12010298EX\", \"AssetTag23121309EX\"],\n        \"tags\" => [%{\"Key\" => \"Name\", \"Value\" => \"CodeDeployDemo-OnPrem\"}]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.RemoveTagsFromOnPremisesInstances\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#remove_tags_from_on_premises_instances/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.skip_wait_time_for_instance_termination/1","doc":"In a blue/green deployment, overrides any specified wait time and starts terminating instances\nimmediately after the traffic routing is complete","ref":"ExAws.CodeDeploy.html#skip_wait_time_for_instance_termination/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.skip_wait_time_for_instance_termination/1","doc":"iex> ExAws.CodeDeploy.skip_wait_time_for_instance_termination(\"d-UBCT41FSL\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentId\" => \"d-UBCT41FSL\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.SkipWaitTimeForInstanceTermination\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#skip_wait_time_for_instance_termination/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.stop_deployment/2","doc":"Attempts to stop an ongoing deployment.","ref":"ExAws.CodeDeploy.html#stop_deployment/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.stop_deployment/2","doc":"iex> ExAws.CodeDeploy.stop_deployment(\"i-123434\")\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\"deploymentId\" => \"i-123434\"},\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.StopDeployment\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#stop_deployment/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.tag_resource/2","doc":"Associates the list of tags in the input tags parameter with the resource identified by the\nresource_arn input parameter","ref":"ExAws.CodeDeploy.html#tag_resource/2"},{"type":"function","title":"Examples - ExAws.CodeDeploy.tag_resource/2","doc":"iex> resource_arn = \"arn:aws:codedeploy:us-west-2:111122223333:application:testApp\"\n    iex> tags = [%{key: \"Name\", value: \"testName\"}, %{key: \"Type\", value: \"testType\"}]\n    iex> ExAws.CodeDeploy.tag_resource(resource_arn, tags)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"Tags\" => [\n          %{\"Key\" => \"Name\", \"Value\" => \"testName\"},\n          %{\"Key\" => \"Type\", \"Value\" => \"testType\"}\n        ],\n        \"resourceArn\" => \"arn:aws:codedeploy:us-west-2:111122223333:application:testApp\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.TagResource\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#tag_resource/2-examples"},{"type":"function","title":"ExAws.CodeDeploy.untag_resource/2","doc":"Disassociates a resource from a list of tags. The resource is identified by the resource_arn input\nparameter. The tags are identified by the list of keys in the tag_keys input parameter","ref":"ExAws.CodeDeploy.html#untag_resource/2"},{"type":"function","title":"Example - ExAws.CodeDeploy.untag_resource/2","doc":"iex> resource_arn = \"arn:aws:codedeploy:us-west-2:111122223333:application:testApp\"\n    iex> tag_keys = [\"key1\", \"key2\"]\n    iex> ExAws.CodeDeploy.untag_resource(resource_arn, tag_keys)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"ResourceArn\" => \"arn:aws:codedeploy:us-west-2:111122223333:application:testApp\",\n        \"TagKeys\" => [[\"key1\", \"key2\"]]\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.UntagResource\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#untag_resource/2-example"},{"type":"function","title":"ExAws.CodeDeploy.update_application/2","doc":"Changes the name of an application.","ref":"ExAws.CodeDeploy.html#update_application/2"},{"type":"function","title":"ExAws.CodeDeploy.update_deployment_group/4","doc":"Changes information about a deployment group. See `create_deployment_group/4`\n\nIf you do not want to change the service_role_arn pass nil. This will exclude that data from the\nAPI call. Passing the current service_role_arn works as well.","ref":"ExAws.CodeDeploy.html#update_deployment_group/4"},{"type":"function","title":"Examples - ExAws.CodeDeploy.update_deployment_group/4","doc":"iex> application_name = \"WordPress_App\"\n    iex> deployment_group_name = \"WordPress_DG\"\n    iex> service_role_arn = \"arn:aws:iam::123456789012:role/CodeDeployDemoRole\"\n    iex> deployment_group_details = %{\n    ...>   auto_scaling_groups: [\"CodeDeployDemo-ASG\"],\n    ...>   deployment_config_name: \"CodeDeployDefault.OneAtATime\",\n    ...>   ec2_tag_filters: [%{key: \"Name\", value: \"CodeDeployDemo\", type: \"KEY_AND_VALUE\"}]\n    ...> }\n    iex> ExAws.CodeDeploy.update_deployment_group(application_name, deployment_group_name, service_role_arn, deployment_group_details)\n    %ExAws.Operation.JSON{\n      stream_builder: nil,\n      http_method: :post,\n      parser: &Function.identity/1,\n      error_parser: &Function.identity/1,\n      path: \"/\",\n      data: %{\n        \"applicationName\" => \"WordPress_App\",\n        \"autoScalingGroups\" => [\"CodeDeployDemo-ASG\"],\n        \"currentDeploymentGroupName\" => \"WordPress_DG\",\n        \"deploymentConfigName\" => \"CodeDeployDefault.OneAtATime\",\n        \"ec2TagFilters\" => [\n          %{\"Key\" => \"Name\", \"Type\" => \"KEY_AND_VALUE\", \"Value\" => \"CodeDeployDemo\"}\n        ],\n        \"serviceRoleArn\" => \"arn:aws:iam::123456789012:role/CodeDeployDemoRole\"\n      },\n      params: %{},\n      headers: [\n        {\"x-amz-target\", \"CodeDeploy_20141006.UpdateDeploymentGroup\"},\n        {\"content-type\", \"application/x-amz-json-1.1\"}\n      ],\n      service: :codedeploy,\n      before_request: nil\n    }","ref":"ExAws.CodeDeploy.html#update_deployment_group/4-examples"},{"type":"type","title":"ExAws.CodeDeploy.action/0","doc":"The `action` key in the `t:green_fleet_provisioning_option/0` has a value\nthat defines information about instances in the replacement environment\n\nValid Values\n```\n[\"DISCOVER_EXISTING\", \"COPY_AUTO_SCALING_GROUP\"]\n```\n\n- \"DISCOVER_EXISTING\": Use instances that already exist or will be created manually.\n- \"COPY_AUTO_SCALING_GROUP\": Use settings from a specified Auto Scaling group to define and create\ninstances in a new Auto Scaling group.","ref":"ExAws.CodeDeploy.html#t:action/0"},{"type":"type","title":"ExAws.CodeDeploy.action_on_timeout/0","doc":"Information about when to reroute traffic from an original environment to a\nreplacement environment in a blue/green deployment.\n\nValue values:\n```\n[\"CONTINUE_DEPLOYMENT\", \"STOP_DEPLOYMENT\"]\n```\n- \"CONTINUE_DEPLOYMENT\": Register new instances with the load balancer immediately after the\n  new application revision is installed on the instances in the replacement environment.\n-\"STOP_DEPLOYMENT\": Do not register new instances with a load balancer unless traffic\n  rerouting is started using ContinueDeployment. If traffic rerouting is not started before\n  the end of the specified wait period, the deployment status is changed to Stopped.","ref":"ExAws.CodeDeploy.html#t:action_on_timeout/0"},{"type":"type","title":"ExAws.CodeDeploy.alarm/0","doc":"Information about an alarm.\n\n- name - The name of the alarm. Maximum length is 255 characters.\n  Each alarm name can be used only once in a list of alarms.","ref":"ExAws.CodeDeploy.html#t:alarm/0"},{"type":"type","title":"ExAws.CodeDeploy.alarm_configuration/0","doc":"Information about alarms associated with a deployment or\ndeployment group\n\n- alarms - A list of alarms configured for the deployment or\n  deployment group. A maximum of 10 alarms can be added.\n- enabled - Indicates whether the alarm configuration is enabled.\n- ignore_poll_alarm_failure - Indicates whether a deployment should\n  continue if information about the current state of alarms cannot\n  be retrieved from Amazon CloudWatch. The default value is false.","ref":"ExAws.CodeDeploy.html#t:alarm_configuration/0"},{"type":"type","title":"ExAws.CodeDeploy.app_spec_content/0","doc":"A revision for an AWS Lambda or Amazon ECS deployment that is a YAML-formatted\nor JSON-formatted string. For AWS Lambda and Amazon ECS deployments, the revision\nis the same as the AppSpec file. This method replaces the deprecated\nRawString data type.\n\n- content -  The YAML-formatted or JSON-formatted revision string. For an AWS Lambda deployment,\n  the content includes a Lambda function name, the alias for its original version, and the alias\n  for its replacement version. The deployment shifts traffic from the original version of the\n  Lambda function to the replacement version. For an Amazon ECS deployment, the content includes\n  the task name, information about the load balancer that serves traffic to the container, and\n  more. For both types of deployments, the content can specify Lambda functions that run at\n  specified hooks, such as BeforeInstall, during a deployment.\n- sha256 - The SHA256 hash value of the revision content.","ref":"ExAws.CodeDeploy.html#t:app_spec_content/0"},{"type":"type","title":"ExAws.CodeDeploy.application_name/0","doc":"Name of the application. Minimum length of 1. Maximum length of 100.","ref":"ExAws.CodeDeploy.html#t:application_name/0"},{"type":"type","title":"ExAws.CodeDeploy.application_revision_sort_by/0","doc":"The column name to use to sort the list results.\n\nValid values\n```\n[\"registerTime\", \"firstUsedTime\", \"lastUsedTime\"]\n```\n\n- \"registerTime\": Sort by the time the revisions were registered with AWS CodeDeploy.\n- \"firstUsedTime\": Sort by the time the revisions were first used in a deployment.\n- \"lastUsedTime\": Sort by the time the revisions were last used in a deployment.\n\nIf not specified or set to null, the results are returned in an arbitrary order.","ref":"ExAws.CodeDeploy.html#t:application_revision_sort_by/0"},{"type":"type","title":"ExAws.CodeDeploy.auto_rollback_configuration/0","doc":"Information about a configuration for automatically rolling back\nto a previous version of an application revision when a deployment\nis not completed successfully.\n\n- enabled - Indicates whether a defined automatic rollback\n  configuration is currently enabled.\n- events - The event type or types that trigger a rollback. Valid\n  values are: \"DEPLOYMENT_FAILURE\", \"DEPLOYMENT_STOP_ON_ALARM\",\n  \"DEPLOYMENT_STOP_ON_REQUEST\"","ref":"ExAws.CodeDeploy.html#t:auto_rollback_configuration/0"},{"type":"type","title":"ExAws.CodeDeploy.auto_scaling_group/0","doc":"Information about an Auto Scaling group\n\n- hook - The name of the launch hook that CodeDeploy installed into the Auto Scaling group\n- name - The Auto Scaling group name\n- termination_hook -The name of the termination hook that CodeDeploy installed into the Auto\n  Scaling group","ref":"ExAws.CodeDeploy.html#t:auto_scaling_group/0"},{"type":"type","title":"ExAws.CodeDeploy.blue_green_deployment_configuration/0","doc":"Information about blue/green deployment options for a deployment group\n\n- deployment_ready_option - Information about the action to take when newly provisioned instances\n  are ready to receive traffic in a blue/green deployment. See `t:deployment_ready_option/0`\n- green_fleet_provisioning_option - Information about how instances are provisioned for a\n  replacement environment in a blue/green deployment. See `t:green_fleet_provisioning_option/0`\n- terminate_blue_instances_on_deployment_success - Information about whether to terminate\n  instances in the original fleet during a blue/green deployment. See\n  `t:terminate_blue_instances_on_deployment_success/0`","ref":"ExAws.CodeDeploy.html#t:blue_green_deployment_configuration/0"},{"type":"type","title":"ExAws.CodeDeploy.bundle_type/0","doc":"The file type of the application revision.\n\n Valid Values\n ```\n [\"tar\", \"tgz\", \"zip\", \"YAML\", \"JSON\"]\n ```","ref":"ExAws.CodeDeploy.html#t:bundle_type/0"},{"type":"type","title":"ExAws.CodeDeploy.compute_platform/0","doc":"The destination platform type for the deployment.\n\nValid values\n```\n[\"Server\", \"Lambda\", \"ECS\"]\n```","ref":"ExAws.CodeDeploy.html#t:compute_platform/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_config_name/0","doc":"The name of a deployment configuration associated with the user or AWS account. Minimum length\nallowed is 1. Maximum length is 100.","ref":"ExAws.CodeDeploy.html#t:deployment_config_name/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_config_optional_details/0","doc":"Optional arguments to the `create_deployment_config/2` function\n\n- minimim_healthy_hosts - The minimum number of healthy instances that should be available at any\n  time during the deployment. There are two parameters expected in the input: type and value.\n- traffic_routing_config - The configuration that specifies how the deployment traffic is routed\n- compute_platform - The destination platform type for the deployment (Lambda, Server, or ECS)\n- zonal_config - Configure the ZonalConfig object if you want AWS CodeDeploy to deploy your\n  application to one Availability Zone at a time, within an AWS Region.","ref":"ExAws.CodeDeploy.html#t:deployment_config_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_group_name/0","doc":"Name of the deployment group. Minimum length of 1. Maximum length of 100.","ref":"ExAws.CodeDeploy.html#t:deployment_group_name/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_group_optional_details/0","doc":"Optional arguments to the `create_deployment_group/4` function\n\n- deployment_config_name - If specified, the deployment configuration name can be either one of\n  the predefined configurations provided with AWS CodeDeploy or a custom deployment configuration\n  that you create by calling the create deployment configuration operation.\n- ec2_tag_filters -The Amazon EC2 tags on which to filter. The deployment group includes Amazon\n  EC2 instances with any of the specified tags. Cannot be used in the same call as ec2_tag_set.\n- on_premises_instance_tag_filters - The on-premises instance tags on which to filter. The\n  deployment group includes on-premises instances with any of the specified tags. Cannot be used\n  in the same call as on_premises_tag_set.\n- auto_scaling_groups - A list of associated Amazon EC2 Auto Scaling groups\n- trigger_configurations - Information about triggers to create when the deployment group is\n  created.\n- alarm_configuration - Information to add about Amazon CloudWatch alarms when the deployment\n  group is created\n- auto_rollback_configuration - Configuration information for an automatic rollback that is added\n  when a deployment group is created.\n- outdated_instances_strategy - Indicates what happens when new Amazon EC2 instances are launched\n  mid-deployment and do not receive the deployed application revision.\n- deployment_style - Information about the type of deployment, in-place or blue/green, that you\n  want to run and whether to route deployment traffic behind a load balancer\n- blue_green_deployment_configuration - Information about blue/green deployment options for a\n  deployment group.\n- load_balancer_info - Information about the load balancer used in a deployment\n- ec2_tag_set - Information about groups of tags applied to Amazon EC2 instances. The deployment\n  group includes only Amazon EC2 instances identified by all the tag groups. Cannot be used in the\n  same call as ec2_tag_filters\n- ecs_services - The target Amazon ECS services in the deployment group. This applies only to\n  deployment groups that use the Amazon ECS compute platform. A target Amazon ECS service is\n  specified as an Amazon ECS cluster and service name pair using the format\n  ` : `\n- on_premises_tag_set - Information about groups of tags applied to on-premises instances. The\n  deployment group includes only on-premises instances identified by all of the tag groups. Cannot\n  be used in the same call as on_premises_instance_tag_filters.\n- tags - The metadata that you apply to CodeDeploy deployment groups to help you organize and\n  categorize them. Each tag consists of a key and an optional value, both of which you define.\n- termination_hook_enabled - This parameter only applies if you are using CodeDeploy with Amazon\n  EC2 Auto Scaling.","ref":"ExAws.CodeDeploy.html#t:deployment_group_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_id/0","doc":"Each deployment is assigned a unique id","ref":"ExAws.CodeDeploy.html#t:deployment_id/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_option/0","doc":"Indicates whether to route deployment traffic behind a load balancer.\n\nValid Values:\n```\n[\"WITH_TRAFFIC_CONTROL\", \"WITHOUT_TRAFFIC_CONTROL\"]\n```","ref":"ExAws.CodeDeploy.html#t:deployment_option/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_optional_details/0","doc":"Optional input to the `create_deployment/2` function\n\nThe required application name is passed in as the first argument\nseparately from the map.\n\n- deployment_group_name - The name of the deployment group\n- revision - The type and location of the revision to deploy\n- deployment_config_name - The name of a deployment configuration associated with the user or AWS\n  account. If not specified, the value configured in the deployment group is used as the default.\n  If the deployment group does not have a deployment configuration associated with it,\n  CodeDeployDefault.OneAtATime is used by default.\n- description - A comment about the deployment\n- ignore_application_stop_failures - boolean value that has the following implications:\n  - If true, then if an ApplicationStop, BeforeBlockTraffic, or AfterBlockTraffic deployment\n  lifecycle event to an instance fails, then the deployment continues to the next deployment\n  lifecycle event. For example, if ApplicationStop fails, the deployment continues with\n  DownloadBundle. If BeforeBlockTraffic fails, the deployment continues with BlockTraffic. If\n  AfterBlockTraffic fails, the deployment continues with ApplicationStop.\n  - If false or not specified, then if a lifecycle event fails during a deployment to an instance,\n  that deployment fails. If deployment to that instance is part of an overall deployment and the\n  number of healthy hosts is not less than the minimum number of healthy hosts, then a deployment\n  to the next instance is attempted.\n  - During a deployment, the AWS CodeDeploy agent runs the scripts specified for ApplicationStop,\n  BeforeBlockTraffic, and AfterBlockTraffic in the AppSpec file from the previous successful\n  deployment. (All other scripts are run from the AppSpec file in the current deployment.) If one\n  of these scripts contains an error and does not run successfully, the deployment can fail.\n  - If the cause of the failure is a script from the last successful deployment that will never run\n  successfully, create a new deployment and use ignoreApplicationStopFailures to specify that the\n  ApplicationStop, BeforeBlockTraffic, and AfterBlockTraffic failures should be ignored.\n- target_instances - Information about the instances that belong to the replacement environment in\n  a blue/green deployment\n- auto_rollback_configuration - Configuration information for an automatic rollback that is added\n  when a deployment is created\n- update_outdated_instances_only - Indicates whether to deploy to all instances or only to\n  instances that are not running the latest application revision.\n- file_exists_behavior - Information about how AWS CodeDeploy handles files that already exist in\n  a deployment target location but weren't part of the previous successful deployment.\n- override_alarm_configuration -","ref":"ExAws.CodeDeploy.html#t:deployment_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_ready_option/0","doc":"Information about how traffic is rerouted to instances in a replacement environment in a\nblue/green deployment\n\n- action_on_timeout - Information about when to reroute traffic from an original environment to a\nreplacement environment in a blue/green deployment.\n- wait_time_in_minutes - The number of minutes to wait before the status of a blue/green\n  deployment is changed to Stopped if rerouting is not started manually. Applies only to the\n  \"STOP_DEPLOYMENT\" option for action_on_timeout.","ref":"ExAws.CodeDeploy.html#t:deployment_ready_option/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_style/0","doc":"Information about the type of deployment, either in-place or blue/green, you want to run and\nwhether to route deployment traffic behind a load balancer.\n\n- deployment_option - Indicates whether to route deployment traffic behind a load balancer.\n- deployment_type - Indicates whether to run an in-place deployment or a blue/green deployment.","ref":"ExAws.CodeDeploy.html#t:deployment_style/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_type/0","doc":"Indicates whether to run an in-place deployment or a blue/green deployment.\n\nValue values\n```\n[\"IN_PLACE\", \"BLUE_GREEN\"]\n```","ref":"ExAws.CodeDeploy.html#t:deployment_type/0"},{"type":"type","title":"ExAws.CodeDeploy.deployment_wait_type/0","doc":"The status of the deployment's waiting period. \"READY_WAIT\" indicates that the deployment is ready\nto start shifting traffic. \"TERMINATION_WAIT\" indicates that the traffic is shifted, but the\noriginal target is not terminated.\n\nValid values:\n```\n[\"READY_WAIT\", \"TERMINATION_WAIT\"]\n```","ref":"ExAws.CodeDeploy.html#t:deployment_wait_type/0"},{"type":"type","title":"ExAws.CodeDeploy.ec2_tag_filter/0","doc":"Information about an EC2 tag filter.\n\n- key - The tag filter key\n- value - The tag filter value\n- type - The tag filter type. Valid values:\n  ```\n  [\"KEY_ONLY\", \"VALUE_ONLY\", \"KEY_AND_VALUE\"\n  ```","ref":"ExAws.CodeDeploy.html#t:ec2_tag_filter/0"},{"type":"type","title":"ExAws.CodeDeploy.ec2_tag_set/0","doc":"Information about groups of Amazon EC2 instance tags.","ref":"ExAws.CodeDeploy.html#t:ec2_tag_set/0"},{"type":"type","title":"ExAws.CodeDeploy.ecs_service/0","doc":"Contains the service and cluster names used to identify an Amazon ECS deployment's target\n\n- cluster_name - The name of the cluster that the Amazon ECS service is associated with.\n- service_name - The name of the target Amazon ECS service","ref":"ExAws.CodeDeploy.html#t:ecs_service/0"},{"type":"type","title":"ExAws.CodeDeploy.ecs_services/0","doc":"A list of `t:ecs_service/0`","ref":"ExAws.CodeDeploy.html#t:ecs_services/0"},{"type":"type","title":"ExAws.CodeDeploy.elb_info/0","doc":"Information about a Classic Load Balancer in Elastic Load Balancing to use in a deployment.\nInstances are registered directly with a load balancer, and traffic is routed to the load\nbalancer.\n\n- name - For blue/green deployments, the name of the Classic Load Balancer that is used to route\n  traffic from original instances to replacement instances in a blue/green deployment. For\n  in-place deployments, the name of the Classic Load Balancer that instances are deregistered from\n  so they are not serving traffic during a deployment, and then re-registered with after the\n  deployment is complete.","ref":"ExAws.CodeDeploy.html#t:elb_info/0"},{"type":"type","title":"ExAws.CodeDeploy.file_exists_behaviour/0","doc":"Information about how AWS CodeDeploy handles files that already exist in a deployment target\nlocation but weren't part of the previous successful deployment.\n\nTakes any of the following values:\n\n- \"DISALLOW\": The deployment fails. This is also the default behavior if no option is specified.\n- \"OVERWRITE\": The version of the file from the application revision currently being deployed\n  replaces the version already on the instance.\n- \"RETAIN\": The version of the file already on the instance is kept and used as part of the new\n  deployment.","ref":"ExAws.CodeDeploy.html#t:file_exists_behaviour/0"},{"type":"type","title":"ExAws.CodeDeploy.git_hub_location/0","doc":"Information about the location of application artifacts stored in GitHub.\n\n- repository - The GitHub account and repository pair that stores a reference\n  to the commit that represents the bundled artifacts for the application\n  revision. Specified as account/repository.\n- commit_id - The SHA1 commit ID of the GitHub commit that represents the\n  bundled artifacts for the application revision.","ref":"ExAws.CodeDeploy.html#t:git_hub_location/0"},{"type":"type","title":"ExAws.CodeDeploy.green_fleet_provisioning_option/0","doc":"Information about the instances that belong to the replacement environment in a blue/green\ndeployment.\n\n- action - The method used to add instances to a replacement environment.","ref":"ExAws.CodeDeploy.html#t:green_fleet_provisioning_option/0"},{"type":"type","title":"ExAws.CodeDeploy.iam_session_arn/0","doc":"AWS Identity and Access Management (IAM) Session Amazon Resource Name (ARN)","ref":"ExAws.CodeDeploy.html#t:iam_session_arn/0"},{"type":"type","title":"ExAws.CodeDeploy.iam_user_arn/0","doc":"AWS Identity and Access Management (IAM) User Amazon Resource Name (ARN)","ref":"ExAws.CodeDeploy.html#t:iam_user_arn/0"},{"type":"type","title":"ExAws.CodeDeploy.include_only_statuses/0","doc":"Deployment status states\n\nValid Values\n```\n[\"Created\",\"Queued\",\"InProgress\",\"Baking\",\"Succeeded\",\"Failed\",\"Stopped\", \"Ready\"]\n```\n\n- \"Created\": Include created deployments in the resulting list.\n- \"Queued\": Include queued deployments in the resulting list.\n- \"In Progress\": Include in-progress deployments in the resulting list.\n- \"Succeeded\": Include successful deployments in the resulting list.\n- \"Failed\": Include failed deployments in the resulting list.\n- \"Stopped\": Include stopped deployments in the resulting list.","ref":"ExAws.CodeDeploy.html#t:include_only_statuses/0"},{"type":"type","title":"ExAws.CodeDeploy.instance_id/0","doc":"instance ID is the 36-character string at the end of your instance's Amazon Resource Name (ARN)","ref":"ExAws.CodeDeploy.html#t:instance_id/0"},{"type":"type","title":"ExAws.CodeDeploy.instance_name/0","doc":"Name of on-premise instance","ref":"ExAws.CodeDeploy.html#t:instance_name/0"},{"type":"type","title":"ExAws.CodeDeploy.instance_status_filter/0","doc":"Indicates an instance's status.\n\nValid values\n```\n[\"Pending\", \"InProgress\", \"Succeeded\", \"Failed\", \"Skipped\", \"Unknown\"]\n```\n\n- \"Pending\": Include those instances with pending deployments.\n- \"InProgress\": Include those instances where deployments are still in progress.\n- \"Succeeded\": Include those instances with successful deployments.\n- \"Failed\": Include those instances with failed deployments.\n- \"Skipped\": Include those instances with skipped deployments.\n- \"Unknown\": Include those instances with deployments in an unknown state.","ref":"ExAws.CodeDeploy.html#t:instance_status_filter/0"},{"type":"type","title":"ExAws.CodeDeploy.instance_type_filter/0","doc":"Indicates an instance in the original environment (\"Blue\") or an instance\nin a replacement environment (\"Green\").\n\nValid Values: \"Blue\" or \"Green\"","ref":"ExAws.CodeDeploy.html#t:instance_type_filter/0"},{"type":"type","title":"ExAws.CodeDeploy.list_applications_revisions_optional_details/0","doc":"Optional arguments to the `list_application_revisions/2` function\n\n- deployed - Whether to list revisions based on whether the revision is the target revision of a\n  deployment grou\n- next_token - An identifier returned from the previous `list_application_revisions/2` call. It\n  can be used to return the next set of applications in the list.\n- s3_bucket - An Amazon S3 bucket name to limit the search for revisions. If set to nil (or not\n  provided), all of the user's buckets are searched.\n- s3_key_prefix - A key prefix for the set of Amazon S3 objects to limit the search for revisions\n- sort_by - The column name to use to sort the list results\n- sort_order - The order in which to sort the list results","ref":"ExAws.CodeDeploy.html#t:list_applications_revisions_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.list_deployment_instances_optional_details/0","doc":"Optional input to the `list_deployment_instances/2` function\n\nPrefer using the map version. The keyword list was defined in\nan earlier version of the library.\n\n- instance_status_filter - A subset of instances to list by status. See `t:instance_status_filter/0`.\n- instance_type_filter - The set of instances in a blue/green deployment, either those in the\n  original environment (\"BLUE\") or those in the replacement environment (\"GREEN\"), for which you\n  want to view instance information.\n- next_token - An identifier returned from the previous  `list_deployment_instances/2` call. It can be\n  used to return the next set of deployment instances in the list.","ref":"ExAws.CodeDeploy.html#t:list_deployment_instances_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.list_deployment_targets_optional_details/0","doc":"Optional parameters for the `list_deployment_targets/1` function\n\n- next_token - A token identifier returned from the previous `list_deployment_targets/1` call. It\n  can be used to return the next set of deployment targets in the list.\n- target_filters - A key used to filter the returned targets.","ref":"ExAws.CodeDeploy.html#t:list_deployment_targets_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.list_deployments_optional_details/0","doc":"Optional input to the `list_deployments/1` function\n\nPrefer using the map version. The keyword list was defined in\nan earlier version of the library.\n\n- application_name - The name of an AWS CodeDeploy application associated with the user or AWS\n  account. If application_name is specified, then deployment_group_name must be specified. If it\n  is not specified, then deployment_group_name must not be specified.\n- deployment_group_name - The name of a deployment group for the specified application. If\n  deployment_group_name is specified, then application_name must be specified. If it is not\n  specified, then applicationName must not be specified.\n- include_only_statuses - A subset of deployments to list by status\n- create_time_range - A time range (start and end) for returning a subset of the list of\n  deployments.\n- next_token - An identifier returned from the previous `list_deployments/1` call. It can be used\n  to return the next set of deployments in the list.","ref":"ExAws.CodeDeploy.html#t:list_deployments_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.list_on_premises_instances_optional_details/0","doc":"Optional parameters for the function `list_on_premises_instances/1`\n\n- next_token - An identifier returned from the previous `list_on_premises_instances/1` call. It can be\n  used to return the next set of on-premises instances in the list.\n- registration_status - The registration status of the on-premises instances. See\n  `t:registration_status/0`\n- tag_filters - The on-premises instance tags that are used to restrict the on-premises instance\n  names returned. See `t:tag_filter_list/0`.","ref":"ExAws.CodeDeploy.html#t:list_on_premises_instances_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.list_state_filter_action/0","doc":"Whether to list revisions based on whether the revision is the target revision of a deployment\ngroup.\n\nValid values\n```\n[\"include\", \"exclude\", \"ignore\"]\n```\n\n- \"include\": List revisions that are target revisions of a deployment group.\n- \"exclude\": Do not list revisions that are target revisions of a deployment group.\n- \"ignore\": List all revisions.","ref":"ExAws.CodeDeploy.html#t:list_state_filter_action/0"},{"type":"type","title":"ExAws.CodeDeploy.list_tags_for_resource_optional_details/0","doc":"Optional parameters for the `list_tags_for_resource/2` function","ref":"ExAws.CodeDeploy.html#t:list_tags_for_resource_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.load_balancer_info/0","doc":"Information about the Elastic Load Balancing load balancer or target group used in a deployment.\n\nYou can use load balancers and target groups in combination. For example, if you have two Classic\nLoad Balancers, and five target groups tied to an Application Load Balancer, you can specify the\ntwo Classic Load Balancers in elb_info_list, and the five target groups in target_group_info_list.\n\n- elb_info_list - An array that contains information about the load balancers to use for load\n  balancing in a deployment. If you're using Classic Load Balancers, specify those load balancers\n  in this array. You can add up to 10 load balancers to the array. If you're using Application\n  Load Balancers or Network Load Balancers, use the target_group_info_list array instead of this one.\n- target_group_info_list - An array that contains information about the target groups to use for\n  load balancing in a deployment. If you're using Application Load Balancers and Network Load\n  Balancers, specify their associated target groups in this array. You can add up to 10 target\n  groups to the array. If you're using Classic Load Balancers, use the elb_info_list array instead\n  of this one.\n- target_group_pair_info_list - The target group pair information. This is a list of\n  `target_group_pair_info/0` objects with a maximum size of one.","ref":"ExAws.CodeDeploy.html#t:load_balancer_info/0"},{"type":"type","title":"ExAws.CodeDeploy.minimim_healthy_hosts/0","doc":"Specify characteristics of minimum healthy hosts\n\n- type - The type parameter takes either of the following values:\n  - \"HOST_COUNT\": The value parameter represents the minimum number of healthy instances as an\n    absolute value.\n  - \"FLEET_PERCENT\": The value parameter represents the minimum number of healthy instances as a\n    percentage of the total number of instances in the deployment. If you specify FLEET_PERCENT,\n    at the start of the deployment, AWS CodeDeploy converts the percentage to the equivalent\n    number of instances and rounds up fractional instances.\n- value - The value parameter takes an integer. For example, to set a minimum of 95% healthy\n  instance, specify a type of FLEET_PERCENT and a value of 95.","ref":"ExAws.CodeDeploy.html#t:minimim_healthy_hosts/0"},{"type":"type","title":"ExAws.CodeDeploy.on_premises_tag_set/0","doc":"Information about groups of on-premises instance tags.\n\non_premises_tag_set_list - A list that contains other lists of on-premises instance tag groups.\nFor an instance to be included in the deployment group, it must be identified by all of the tag\ngroups in the list","ref":"ExAws.CodeDeploy.html#t:on_premises_tag_set/0"},{"type":"type","title":"ExAws.CodeDeploy.outdated_instances_strategy/0","doc":"Indicates what happens when new Amazon EC2 instances are launched mid-deployment and do not\nreceive the deployed application revision.\n\nIf this option is set to \"UPDATE\" or is unspecified, CodeDeploy initiates one or more 'auto-update\noutdated instances' deployments to apply the deployed application revision to the new Amazon EC2\ninstances.\n\nIf this option is set to \"IGNORE\", CodeDeploy does not initiate a deployment to update the new\nAmazon EC2 instances. This may result in instances having different revisions.\n\nValid values\n```\n[\"IGNORE\", \"UPDATE\"]\n```","ref":"ExAws.CodeDeploy.html#t:outdated_instances_strategy/0"},{"type":"type","title":"ExAws.CodeDeploy.paging_options/0","doc":"Some functions take only  an (optional) paging argument. Paging\nis done by passing in the \"nextToken\" returned by a previous call\nto the API endpoint. The value can be passed in as a keyword list,\na Map, or a tuple.","ref":"ExAws.CodeDeploy.html#t:paging_options/0"},{"type":"type","title":"ExAws.CodeDeploy.primitive_tag/0","doc":"In order to provide backward compatability the type `t:primitive_tag/0` is available. With this\ntype a tag consists of a 2-element tuple where the key is the first element and the value is the\nsecond. The new `t:tag/0` type provides greater flexibilty and is preferred. This type can only be\npassed for the functions `create_application/3` and `add_tags_to_on_premises_instances/2`.","ref":"ExAws.CodeDeploy.html#t:primitive_tag/0"},{"type":"type","title":"Example - ExAws.CodeDeploy.primitive_tag/0","doc":"```\nprimitive_tag = {\"my_key\", \"my_value\"}\n```","ref":"ExAws.CodeDeploy.html#t:primitive_tag/0-example"},{"type":"type","title":"ExAws.CodeDeploy.register_application_revision_optional_details/0","doc":"Optional parameters to the function `register_application_revision/3`","ref":"ExAws.CodeDeploy.html#t:register_application_revision_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.register_on_premises_instance_optional_details/0","doc":"Input a user or session arn","ref":"ExAws.CodeDeploy.html#t:register_on_premises_instance_optional_details/0"},{"type":"type","title":"ExAws.CodeDeploy.registration_status/0","doc":"The registration status of the on-premises instances.\n\nValid Values\n```\n[\"Deregistered\"  \"Registered\"]\n```\n\n- \"Deregistered\": Include deregistered on-premises instances in the resulting list.\n- \"Registered\": Include registered on-premises instances in the resulting list.","ref":"ExAws.CodeDeploy.html#t:registration_status/0"},{"type":"type","title":"ExAws.CodeDeploy.resource_arn/0","doc":"The ARN of a CodeDeploy resource\n\nLength Constraints: Minimum length of 1. Maximum length of 1011.","ref":"ExAws.CodeDeploy.html#t:resource_arn/0"},{"type":"type","title":"ExAws.CodeDeploy.revision_location/0","doc":"Information about the location of an application revision\n\n- revision_type -\n- s3_location - Information about the location of a revision stored in Amazon S3.\n- git_hub_location - Information about the location of application artifacts stored in GitHub.\n- app_spec_content - The content of an AppSpec file for an AWS Lambda or Amazon ECS deployment.\n  The content is formatted as JSON or YAML and stored as a RawString.","ref":"ExAws.CodeDeploy.html#t:revision_location/0"},{"type":"type","title":"ExAws.CodeDeploy.revision_type/0","doc":"The type of application revision:\n\nValid Values\n```\n[\"S3\", \"GitHub\",\" String\", \"AppSpecContent\"]\n```\n\n- \"S3\" - An application revision stored in Amazon S3.\n- \"GitHub\" - An application revision stored in GitHub (EC2/On-premises deployments only).\n- \"String\": A YAML-formatted or JSON-formatted string (AWS Lambda deployments only).\n- \"AppSpecContent\": An AppSpecContent object that contains the contents of an AppSpec file for an\n  AWS Lambda or Amazon ECS deployment. The content is formatted as JSON or YAML stored as a\n  RawString.","ref":"ExAws.CodeDeploy.html#t:revision_type/0"},{"type":"type","title":"ExAws.CodeDeploy.s3_location/0","doc":"Information about the location of application artifacts stored in\nAmazon S3.\n\n- bucket - The name of the Amazon S3 bucket where the application\n  revision is stored.\n- bundle_type - The file type of the application revision.\n- e_tag - The ETag of the Amazon S3 object that represents the bundled\n  artifacts for the application revision. If the ETag is not specified\n  as an input parameter, ETag validation of the object is skipped.\n- key - The name of the Amazon S3 object that represents the bundled\n  artifacts for the application revision.\n- version - A specific version of the Amazon S3 object that represents\n  the bundled artifacts for the application revision. If the version is\n  not specified, the system uses the most recent version by default.","ref":"ExAws.CodeDeploy.html#t:s3_location/0"},{"type":"type","title":"ExAws.CodeDeploy.service_instance_label_values/0","doc":"A filter value used to filter deployment targets based on current label\n\nValid Values\n\n```\n[\"Blue\", \"Green\"`]\n```","ref":"ExAws.CodeDeploy.html#t:service_instance_label_values/0"},{"type":"type","title":"ExAws.CodeDeploy.service_role_arn/0","doc":"A service role Amazon Resource Name (ARN) that allows AWS CodeDeploy to act on the user's behalf\nwhen interacting with AWS services.","ref":"ExAws.CodeDeploy.html#t:service_role_arn/0"},{"type":"type","title":"ExAws.CodeDeploy.sort_order/0","doc":"The order in which to sort the list results.\n\nValid values\n```\n[\"ascending\", \"descending\"]\n```\n\n- \"ascending\": ascending order.\n- \"descending\": descending order.","ref":"ExAws.CodeDeploy.html#t:sort_order/0"},{"type":"type","title":"ExAws.CodeDeploy.tag/0","doc":"Information about a tag.\n\n- key - the value contains the tag's key\n- value - the value contains the tag's value","ref":"ExAws.CodeDeploy.html#t:tag/0"},{"type":"type","title":"ExAws.CodeDeploy.tag_filter/0","doc":"Information about an on-premises instance tag filter.\n\n- key - The on-premises instance tag filter key\n- value - The on-premises instance tag filter value\n- type - The on-premises instance tag filter type","ref":"ExAws.CodeDeploy.html#t:tag_filter/0"},{"type":"type","title":"ExAws.CodeDeploy.tag_filter_list/0","doc":"List of `t:tag_filter/0`","ref":"ExAws.CodeDeploy.html#t:tag_filter_list/0"},{"type":"type","title":"ExAws.CodeDeploy.tag_filter_type/0","doc":"Specifies the tag filter type\n\nValid Values\n```\n[\"KEY_ONLY\", \"VALUE_ONLY\", \"KEY_AND_VALUE\"]\n```","ref":"ExAws.CodeDeploy.html#t:tag_filter_type/0"},{"type":"type","title":"ExAws.CodeDeploy.tags/0","doc":"A list of tags","ref":"ExAws.CodeDeploy.html#t:tags/0"},{"type":"type","title":"ExAws.CodeDeploy.target_filters/0","doc":"Filter used with `list_deployment_targets/1`\n\n- target_status - filter deployment targets by current target status\n- service_instance_label - filter deployment targets based on current label","ref":"ExAws.CodeDeploy.html#t:target_filters/0"},{"type":"type","title":"ExAws.CodeDeploy.target_group_info/0","doc":"Information about a target group in Elastic Load Balancing to use in a deployment. Instances are\nregistered as targets in a target group, and traffic is routed to the target group.\n\n- name - For blue/green deployments, the name of the target group that instances in the original\n  environment are deregistered from, and instances in the replacement environment are registered\n  with. For in-place deployments, the name of the target group that instances are deregistered\n  from, so they are not serving traffic during a deployment, and then re-registered with after the\n  deployment is complete.","ref":"ExAws.CodeDeploy.html#t:target_group_info/0"},{"type":"type","title":"ExAws.CodeDeploy.target_group_pair_info/0","doc":"Information about two target groups and how traffic is routed during an Amazon ECS deployment. An\noptional test traffic route can be specified.\n\n- prod_traffic_route - The path used by a load balancer to route production traffic when an Amazon\n  ECS deployment is complete.\n- target_groups - One pair of target groups. One is associated with the original task set. The\n  second is associated with the task set that serves traffic after the deployment is complete.\n- test_traffic_route - An optional path used by a load balancer to route test traffic after an\n  Amazon ECS deployment. Validation can occur while test traffic is served during a deployment.","ref":"ExAws.CodeDeploy.html#t:target_group_pair_info/0"},{"type":"type","title":"ExAws.CodeDeploy.target_id/0","doc":"The unique IDs of the deployment targets. The compute platform of the deployment determines the\ntype of the targets and their formats.\n\n- For deployments that use the EC2/On-premises compute platform, the target IDs are Amazon EC2 or\n  on-premises instances IDs, and their target type is \"instanceTarget\".\n- For deployments that use the AWS Lambda compute platform, the target IDs are the names of Lambda\n  functions, and their target type is \"instanceTarget\".\n- For deployments that use the Amazon ECS compute platform, the target IDs are pairs of Amazon ECS\n  clusters and services specified using the format  : . Their target type\n  is \"ecsTarget\".\n- For deployments that are deployed with AWS CloudFormation, the target IDs are CloudFormation\n  stack IDs. Their target type is \"cloudFormationTarget\".","ref":"ExAws.CodeDeploy.html#t:target_id/0"},{"type":"type","title":"ExAws.CodeDeploy.target_ids/0","doc":"A list of `t:target_id/0`","ref":"ExAws.CodeDeploy.html#t:target_ids/0"},{"type":"type","title":"ExAws.CodeDeploy.target_instances/0","doc":"Information about the instances to be used in the replacement\nenvironment in a blue/green deployment.\n\n- tag_filters - The tag filter key, type, and value used to identify Amazon EC2 instances in a\n  replacement environment for a blue/green deployment. Cannot be used in the same call as\n  ec2_tag_set.\n- auto_scaling_groups - The names of one or more Auto Scaling groups to identify a replacement\n  environment for a blue/green deployment.\n- ec2_tag_set - Information about the groups of Amazon EC2 instance tags that an instance must be\n  identified by in order for it to be included in the replacement environment for a blue/green\n  deployment. Cannot be used in the same call as tag_filters.","ref":"ExAws.CodeDeploy.html#t:target_instances/0"},{"type":"type","title":"ExAws.CodeDeploy.target_status_values/0","doc":"A filter value used to filter deployment targets by current target status\n\nValid Values\n\n```\n[\"Failed\", \"InProgress\", \"Pending\", \"Ready\", \"Skipped\", \"Succeeded\", \"Unknown\"]\n```","ref":"ExAws.CodeDeploy.html#t:target_status_values/0"},{"type":"type","title":"ExAws.CodeDeploy.terminate_blue_instances_on_deployment_success/0","doc":"This parameter only applies if you are using CodeDeploy with Amazon EC2 Auto Scaling.\n\nSet to true to have CodeDeploy install a termination hook into your Auto Scaling group when you\ncreate a deployment group. When this hook is installed, CodeDeploy will perform termination\ndeployments.","ref":"ExAws.CodeDeploy.html#t:terminate_blue_instances_on_deployment_success/0"},{"type":"type","title":"ExAws.CodeDeploy.time_based_canary/0","doc":"A configuration that shifts traffic from one version of a Lambda function or ECS task set to\nanother in two increments. The original and target Lambda function versions or ECS task sets are\nspecified in the deployment's AppSpec file\n\n- canary_interval -The number of minutes between the first and second traffic shifts of a\n  TimeBasedCanary deployment.\n- canary_percentage - The percentage of traffic to shift in the first increment of a\n  TimeBasedCanary deployment.","ref":"ExAws.CodeDeploy.html#t:time_based_canary/0"},{"type":"type","title":"ExAws.CodeDeploy.time_based_linear/0","doc":"A configuration that shifts traffic from one version of a Lambda function or ECS task set to\nanother in equal increments, with an equal number of minutes between each increment. The original\nand target Lambda function versions or ECS task sets are specified in the deployment's AppSpec\nfile\n\n- linear_interval - The number of minutes between each incremental traffic shift of a\n  TimeBasedLinear deployment.\n- linear_percentage - The percentage of traffic that is shifted at the start of each increment of\n  a TimeBasedLinear deployment.","ref":"ExAws.CodeDeploy.html#t:time_based_linear/0"},{"type":"type","title":"ExAws.CodeDeploy.time_range/0","doc":"Information about a time range.\n\n- start -The start time of the time range. Specify nil to leave the start time open-ended.\n- end - The end time of the time range. Specify nil to leave the end time open-ended.","ref":"ExAws.CodeDeploy.html#t:time_range/0"},{"type":"type","title":"ExAws.CodeDeploy.token_name/0","doc":"The name of the GitHub account connection","ref":"ExAws.CodeDeploy.html#t:token_name/0"},{"type":"type","title":"ExAws.CodeDeploy.traffic_route/0","doc":"Information about a listener. The listener contains the path used to route traffic that is\nreceived from the load balancer to a target group.\n\n- listener_arns - The Amazon Resource Name (ARN) of one listener. The listener identifies the\n  route between a target group and a load balancer. This is an array of strings with a maximum\n  size of one.","ref":"ExAws.CodeDeploy.html#t:traffic_route/0"},{"type":"type","title":"ExAws.CodeDeploy.traffic_routing_config/0","doc":"The configuration that specifies how the deployment traffic is routed\n\n- type - The type of traffic shifting (TimeBasedCanary or TimeBasedLinear) used by a deployment\n  configuration. Valid values are \"TimeBasedCanary\", \"TimeBasedLinear\" or \"AllAtOnce\"\n- time_based_canary - `t:time_based_canary/0`\n- time_based_linear - `t:time_based_linear/0`","ref":"ExAws.CodeDeploy.html#t:traffic_routing_config/0"},{"type":"type","title":"ExAws.CodeDeploy.trigger_configuration/0","doc":"Information about notification triggers for the deployment group\n\n- trigger_events - The event type or types for which notifications are triggered. A list\n  of `t:trigger_event/0`\n- trigger_name - The name of the notification trigger.\n- trigger_target_arn - The Amazon Resource Name (ARN) of the Amazon Simple Notification Service\n  topic through which notifications about deployment or instance events are sent.","ref":"ExAws.CodeDeploy.html#t:trigger_configuration/0"},{"type":"type","title":"ExAws.CodeDeploy.trigger_configurations/0","doc":"A list of `t:trigger_configuration/0`","ref":"ExAws.CodeDeploy.html#t:trigger_configurations/0"},{"type":"type","title":"ExAws.CodeDeploy.trigger_event/0","doc":"A trigger event\n\nValid Values:\n```\n[\"DeploymentStart\", \"DeploymentSuccess\", \"DeploymentFailure\", \"DeploymentStop\",\n\"DeploymentRollback\", \"DeploymentReady\", \"InstanceStart\", \"InstanceSuccess\",\n\"InstanceFailure\", \"InstanceReady\"]\n```","ref":"ExAws.CodeDeploy.html#t:trigger_event/0"},{"type":"type","title":"ExAws.CodeDeploy.zonal_config/0","doc":"Configure the ZonalConfig object if you want AWS CodeDeploy to deploy your application to one\nAvailability Zone at a time, within an AWS Region. By deploying to one Availability Zone at a\ntime, you can expose your deployment to a progressively larger audience as confidence in the\ndeployment's performance and viability grows. If you don't configure the ZonalConfig object,\nCodeDeploy deploys your application to a random selection of hosts across a Region.\n\n- first_zone_monitor_duration_in_seconds - The period of time, in seconds, that CodeDeploy must\n  wait after completing a deployment to the first Availability Zone. CodeDeploy will wait this\n  amount of time before starting a deployment to the second Availability Zone. You might set this\n  option if you want to allow extra bake time for the first Availability Zone. If you don't\n  specify a value for firstZoneMonitorDurationInSeconds, then CodeDeploy uses the\n  monitorDurationInSeconds value for the first Availability Zone.\n- minimim_healthy_hosts_per_zone - The number or percentage of instances that must remain\n  available per Availability Zone during a deployment. `t:minimim_healthy_hosts/0`\n- monitor_duration_in_seconds - The period of time, in seconds, that CodeDeploy must wait after\n  completing a deployment to an Availability Zone. CodeDeploy will wait this amount of time before\n  starting a deployment to the next Availability Zone. Consider adding a monitor duration to give\n  the deployment some time to prove itself (or 'bake') in one Availability Zone before it is\n  released in the next zone. If you don't specify a monitor_duration_in_seconds, CodeDeploy starts\n  deploying to the next Availability Zone immediately.","ref":"ExAws.CodeDeploy.html#t:zonal_config/0"},{"type":"module","title":"ExAws.CodeDeploy.Utils","doc":"Helper utility functions","ref":"ExAws.CodeDeploy.Utils.html"},{"type":"function","title":"ExAws.CodeDeploy.Utils.camelize/2","doc":"Camelize an atom or string value\n\nThis works as expected if the val uses an underscore or\nhyphen to separate words. This only works for atoms and\nstrings. Passing another value type (integer, list, map)\nwill raise exception.","ref":"ExAws.CodeDeploy.Utils.html#camelize/2"},{"type":"function","title":"Example - ExAws.CodeDeploy.Utils.camelize/2","doc":"iex> ExAws.CodeDeploy.Utils.camelize(:test_val)\n    \"testVal\"\n\n    iex> ExAws.CodeDeploy.Utils.camelize(\"test_val\")\n    \"testVal\"\n\n    iex> ExAws.CodeDeploy.Utils.camelize(\"abc-def-a123\")\n    \"abcDefA123\"\n\n    iex> ExAws.CodeDeploy.Utils.camelize(:A_test_of_initial_cap)\n    \"aTestOfInitialCap\"","ref":"ExAws.CodeDeploy.Utils.html#camelize/2-example"},{"type":"function","title":"ExAws.CodeDeploy.Utils.camelize_map/2","doc":"Camelize Map keys, including traversing values that are also Maps.\n\nThe caller can pass in an argument to indicate whether the first letter of a key for the map are\ndowncased or capitalized.\n\nKeys should be atoms and follow the rules listed for the `camelize/2` function.","ref":"ExAws.CodeDeploy.Utils.html#camelize_map/2"},{"type":"function","title":"Example - ExAws.CodeDeploy.Utils.camelize_map/2","doc":"iex> val = %{abc_def: 123, another_val: \"val2\"}\n    iex> ExAws.CodeDeploy.Utils.camelize_map(val)\n    %{\"abcDef\" => 123, \"anotherVal\" => \"val2\"}\n\n    iex> val = %{abc_def: 123, another_val: %{embed_value: \"val2\"}}\n    iex> ExAws.CodeDeploy.Utils.camelize_map(val)\n    %{\"abcDef\" => 123, \"anotherVal\" => %{\"embedValue\" => \"val2\"}}\n\n    iex> val = %{abc_def: 123, another_val: %{embed_value: \"val2\"}}\n    iex> ExAws.CodeDeploy.Utils.camelize_map(val, %{subkeys: %{}, keys: %{}, default: :upper})\n    %{\"AbcDef\" => 123, \"AnotherVal\" => %{\"EmbedValue\" => \"val2\"}}","ref":"ExAws.CodeDeploy.Utils.html#camelize_map/2-example"},{"type":"function","title":"ExAws.CodeDeploy.Utils.camelize_rules/0","doc":"Return the default camelize rules\n\nA caller can override this by creating a `t:camelize_rules/0` and passing\nit into functions instead of the default.","ref":"ExAws.CodeDeploy.Utils.html#camelize_rules/0"},{"type":"function","title":"ExAws.CodeDeploy.Utils.keyword_to_map/1","doc":"If val is a Keyword then convert to a Map, else\nreturn val","ref":"ExAws.CodeDeploy.Utils.html#keyword_to_map/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.Utils.keyword_to_map/1","doc":"iex> ExAws.CodeDeploy.Utils.keyword_to_map([{:a, 7}, {:b, \"abc\"}])\n    %{a: 7, b: \"abc\"}\n\n    iex> ExAws.CodeDeploy.Utils.keyword_to_map(%{a: 7, b: %{c: \"abc\"}})\n    %{a: 7, b: %{c: \"abc\"}}\n\n    iex> ExAws.CodeDeploy.Utils.keyword_to_map([1, 2, 3])\n    [1, 2, 3]","ref":"ExAws.CodeDeploy.Utils.html#keyword_to_map/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.Utils.normalize_paging/1","doc":"Take the various forms of allowed paging options and create a\n`%{next_token: val}`","ref":"ExAws.CodeDeploy.Utils.html#normalize_paging/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.Utils.normalize_paging/1","doc":"# Passing an unexpected value (no paging found) returns an empty map\n    iex> ExAws.CodeDeploy.Utils.normalize_paging([])\n    %{}\n\n    # Different approaches to defining Keyword list work\n    iex> ExAws.CodeDeploy.Utils.normalize_paging([{:next_token, \"123\"}])\n    %{next_token: \"123\"}\n\n    iex> ExAws.CodeDeploy.Utils.normalize_paging([next_token: \"123\"])\n    %{next_token: \"123\"}\n\n    # Pass a tuple, no list\n    iex> ExAws.CodeDeploy.Utils.normalize_paging({:next_token, \"123\"})\n    %{next_token: \"123\"}\n\n    # Pass in data already formatted, returns the same data\n    iex> ExAws.CodeDeploy.Utils.normalize_paging(%{next_token: \"123\"})\n    %{next_token:  \"123\"}","ref":"ExAws.CodeDeploy.Utils.html#normalize_paging/1-examples"},{"type":"function","title":"ExAws.CodeDeploy.Utils.normalize_tags/1","doc":"Take a list of tag and convert it into a list where each elemet\nis a map with atom keys.","ref":"ExAws.CodeDeploy.Utils.html#normalize_tags/1"},{"type":"function","title":"Examples - ExAws.CodeDeploy.Utils.normalize_tags/1","doc":"iex> ExAws.CodeDeploy.Utils.normalize_tags([])\n    []\n\n    iex> ExAws.CodeDeploy.Utils.normalize_tags([{\"my_key\", \"value1\"}])\n    [%{key: \"my_key\", value: \"value1\"}]","ref":"ExAws.CodeDeploy.Utils.html#normalize_tags/1-examples"},{"type":"type","title":"ExAws.CodeDeploy.Utils.camelize_rules/0","doc":"The camelize, camelize_list, and camelize_map take an argument that is\na data structure providing rules for capitalization.\n\n- subkeys - this provides a map that indicates how keys found under this\n  particular key should be camelized\n- keys - this provides a map that indicate how particular keys should be\n  camelized\n- default - indicates whether `:upper` or `:lower` is used by default","ref":"ExAws.CodeDeploy.Utils.html#t:camelize_rules/0"},{"type":"extras","title":"AWS CodeDeploy API","doc":"# AWS CodeDeploy API\n\nAWS Code Deploy Service module for [ex_aws](https://github.com/ex-aws/ex_aws).","ref":"readme.html"},{"type":"extras","title":"Installation - AWS CodeDeploy API","doc":"The package can be installed by adding ex_aws_code_deploy to your list of dependencies in mix.exs along with :ex_aws and your preferred JSON codec / http client. Example:\n\n```elixir\ndef deps do\n  [\n    {:ex_aws, \"~> 2.0\"},\n    {:ex_aws_code_deploy, \"~> 2.0\"},\n    {:poison, \"~> 3.0\"},\n    {:hackney, \"~> 1.9\"},\n  ]\nend\n```","ref":"readme.html#installation"},{"type":"extras","title":"Documentation - AWS CodeDeploy API","doc":"* [ex_aws](https://hexdocs.pm/ex_aws)\n* [AWS CodeDeploy API](https://docs.aws.amazon.com/codedeploy/latest/APIReference/API_ListApplications.html)\n* [Go API for CodeDeploy](https://github.com/aws/aws-sdk-go/blob/master/models/apis/codedeploy/2014-10-06/api-2.json)","ref":"readme.html#documentation"},{"type":"extras","title":"License - AWS CodeDeploy API","doc":"[License](LICENSE)","ref":"readme.html#license"},{"type":"extras","title":"Changelog","doc":"v2.1.0\n------\n#### Important Changes\n  - Missing functions that are part of the API are added\n  - Previously existing functions that took keyword lists still will work but\n    using the new Map types to provide optional data is preferred\n#### Enhancements\n  - Use Github Workflows to test with multiple Elixir versions, credo, dialyzer\n  - Update dependencies\n  - More doctests\n\nv2.0.0\n------\n#### First Release\n  - Initial version for hex.pm with most functions for API in place","ref":"changelog.html"},{"type":"extras","title":"License","doc":"MIT License\n\nCopyright (c) 2018 Vonage, Inc.\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the \"Software\"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in all\ncopies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED \"AS IS\", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE\nSOFTWARE.","ref":"license.html"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}